#include "casadi/core/casadi_calculus.hpp"
#include "casadi/core/casadi_exception.hpp"
#include "casadi/core/casadi_meta.hpp"
#include "casadi/core/casadi_options.hpp"
#include "casadi/core/casadi_types.hpp"
#include "casadi/core/function/control_simulator.hpp"
#include "casadi/core/function/custom_function.hpp"
#include "casadi/core/function/external_function.hpp"
#include "casadi/core/function/function.hpp"
#include "casadi/core/function/homotopy_nlp_solver.hpp"
#include "casadi/core/function/implicit_function.hpp"
#include "casadi/core/function/integrator.hpp"
#include "casadi/core/function/io_interface.hpp"
#include "casadi/core/function/linear_solver.hpp"
#include "casadi/core/function/lp_solver.hpp"
#include "casadi/core/function/mx_function.hpp"
#include "casadi/core/function/nlp_solver.hpp"
#include "casadi/core/function/nullspace.hpp"
#include "casadi/core/function/ocp_solver.hpp"
#include "casadi/core/function/parallelizer.hpp"
#include "casadi/core/function/qcqp_solver.hpp"
#include "casadi/core/function/qp_solver.hpp"
#include "casadi/core/function/sdp_solver.hpp"
#include "casadi/core/function/sdqp_solver.hpp"
#include "casadi/core/function/simulator.hpp"
#include "casadi/core/function/socp_solver.hpp"
#include "casadi/core/function/stabilized_qp_solver.hpp"
#include "casadi/core/function/sx_function.hpp"
#include "casadi/core/function/symbolic_qr.hpp"
#include "casadi/core/functor.hpp"
#include "casadi/core/generic_type.hpp"
#include "casadi/core/matrix/generic_expression.hpp"
#include "casadi/core/matrix/generic_matrix.hpp"
#include "casadi/core/matrix/matrix.hpp"
#include "casadi/core/matrix/matrix_tools.hpp"
#include "casadi/core/matrix/slice.hpp"
#include "casadi/core/matrix/sparsity.hpp"
#include "casadi/core/matrix/sparsity_tools.hpp"
#include "casadi/core/mx/mx.hpp"
#include "casadi/core/mx/mx_tools.hpp"
#include "casadi/core/options_functionality.hpp"
#include "casadi/core/printable_object.hpp"
#include "casadi/core/shared_object.hpp"
#include "casadi/core/std_vector_tools.hpp"
#include "casadi/core/sx/sx_element.hpp"
#include "casadi/core/sx/sx_tools.hpp"
#include "casadi/core/weak_ref.hpp"
#include "casadi/interfaces/ipopt/ipopt_solver.hpp"
#include <cmath>
#include <sstream>
#include <stdexcept>
#include "../marshal.hpp"

// ================== delete UserType (Namespace ["casadi"]) (Name "IpoptSolver")===============
// classType: UserType (Namespace ["casadi"]) (Name "IpoptSolver")
extern "C"
    void delete_casadi__IpoptSolver(casadi::IpoptSolver* obj);
void delete_casadi__IpoptSolver(casadi::IpoptSolver* obj){
    delete obj;
}

// ================== Constructor method: "CONSTRUCTOR" ===============
// class: "casadi::IpoptSolver"
// cppName: "casadi::IpoptSolver"
// cWrapperName: "casadi__IpoptSolver__CONSTRUCTOR__0"
// protoArgs: "(std::string ** err_msg, casadi::Function* x0)"
// args: "(x0_)"
// rettype: UserType (Namespace ["casadi"]) (Name "IpoptSolver")
// cWrapperRetType: "casadi::IpoptSolver*"
// proto: "casadi::IpoptSolver* casadi__IpoptSolver__CONSTRUCTOR__0(std::string ** err_msg, casadi::Function* x0)"
// call: "casadi::IpoptSolver(x0_)"
// params: [Ref (Const (UserType (Namespace ["casadi"]) (Name "Function")))]
extern "C"
    casadi::IpoptSolver* casadi__IpoptSolver__CONSTRUCTOR__0(std::string ** err_msg, casadi::Function* x0);
casadi::IpoptSolver* casadi__IpoptSolver__CONSTRUCTOR__0(std::string ** err_msg, casadi::Function* x0){
    try {
        casadi::Function x0_ = Marshaling<casadi::Function,casadi::Function*>::marshal(x0);

        casadi::IpoptSolver ret = casadi::IpoptSolver(x0_);
        return WrapReturn< casadi::IpoptSolver*, casadi::IpoptSolver >::wrapReturn( ret );
    } catch (std::exception& ex) {
         *err_msg = new std::string(ex.what());
         return 0;
    }
}


// ================== Constructor method: "CONSTRUCTOR" ===============
// class: "casadi::IpoptSolver"
// cppName: "casadi::IpoptSolver"
// cWrapperName: "casadi__IpoptSolver__CONSTRUCTOR__1"
// protoArgs: "(std::string ** err_msg)"
// args: "()"
// rettype: UserType (Namespace ["casadi"]) (Name "IpoptSolver")
// cWrapperRetType: "casadi::IpoptSolver*"
// proto: "casadi::IpoptSolver* casadi__IpoptSolver__CONSTRUCTOR__1(std::string ** err_msg)"
// call: "casadi::IpoptSolver()"
// params: []
extern "C"
    casadi::IpoptSolver* casadi__IpoptSolver__CONSTRUCTOR__1(std::string ** err_msg);
casadi::IpoptSolver* casadi__IpoptSolver__CONSTRUCTOR__1(std::string ** err_msg){
    try {

        casadi::IpoptSolver ret = casadi::IpoptSolver();
        return WrapReturn< casadi::IpoptSolver*, casadi::IpoptSolver >::wrapReturn( ret );
    } catch (std::exception& ex) {
         *err_msg = new std::string(ex.what());
         return 0;
    }
}


// ================== Static method: "creator" ===============
// class: "casadi::IpoptSolver"
// cppName: "casadi::IpoptSolver::creator"
// cWrapperName: "casadi__IpoptSolver__creator"
// protoArgs: "(std::string ** err_msg, casadi::Function* x0)"
// args: "(x0_)"
// rettype: UserType (Namespace ["casadi"]) (Name "NLPSolver")
// cWrapperRetType: "casadi::NLPSolver*"
// proto: "casadi::NLPSolver* casadi__IpoptSolver__creator(std::string ** err_msg, casadi::Function* x0)"
// call: "casadi::IpoptSolver::creator(x0_)"
// params: [Ref (Const (UserType (Namespace ["casadi"]) (Name "Function")))]
extern "C"
    casadi::NLPSolver* casadi__IpoptSolver__creator(std::string ** err_msg, casadi::Function* x0);
casadi::NLPSolver* casadi__IpoptSolver__creator(std::string ** err_msg, casadi::Function* x0){
    try {
        casadi::Function x0_ = Marshaling<casadi::Function,casadi::Function*>::marshal(x0);

        casadi::NLPSolver ret = casadi::IpoptSolver::creator(x0_);
        return WrapReturn< casadi::NLPSolver*, casadi::NLPSolver >::wrapReturn( ret );
    } catch (std::exception& ex) {
         *err_msg = new std::string(ex.what());
         return 0;
    }
}


// ================== Normal method: "getReducedHessian" ===============
// class: "casadi::IpoptSolver"
// cppName: "casadi::IpoptSolver::getReducedHessian"
// cWrapperName: "casadi__IpoptSolver__getReducedHessian"
// protoArgs: "(std::string ** err_msg, casadi::IpoptSolver* obj)"
// args: "()"
// rettype: UserType (Namespace ["casadi"]) (Name "DMatrix")
// cWrapperRetType: "casadi::DMatrix*"
// proto: "casadi::DMatrix* casadi__IpoptSolver__getReducedHessian(std::string ** err_msg, casadi::IpoptSolver* obj)"
// call: "obj->getReducedHessian()"
// params: []
extern "C"
    casadi::DMatrix* casadi__IpoptSolver__getReducedHessian(std::string ** err_msg, casadi::IpoptSolver* obj);
casadi::DMatrix* casadi__IpoptSolver__getReducedHessian(std::string ** err_msg, casadi::IpoptSolver* obj){
    try {

        casadi::DMatrix ret = obj->getReducedHessian();
        return WrapReturn< casadi::DMatrix*, casadi::DMatrix >::wrapReturn( ret );
    } catch (std::exception& ex) {
         *err_msg = new std::string(ex.what());
         return 0;
    }
}



